Documentation
¶
Overview ¶
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
*
- Copyright 2022 chyroc *
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at *
- http://www.apache.org/licenses/LICENSE-2.0 *
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
Index ¶
- func BitableBlock(token, viewType string) *lark.DocBlock
- func Body(blocks ...*lark.DocBlock) *lark.DocBody
- func CalloutBlock(body *lark.DocBody) *lark.DocBlock
- func ChatGroupBlock(openID string) *lark.DocBlock
- func CodeBlock(language string, body *lark.DocBody) *lark.DocBlock
- func DiagramBlock(diagramType, token string) *lark.DocBlock
- func DocsLinkParagraphElement(val string) *lark.DocParagraphElement
- func EmbeddedPageBlock(typ, url string) *lark.DocBlock
- func EmptySheetBlock(rowSize, columnSize int64) *lark.DocBlock
- func EmptyTableBlock(rowSize, columnSize int64) *lark.DocBlock
- func EndOfZoneDocLocation() *lark.UpdateDocLocation
- func EquationParagraphElement(equation string) *lark.DocParagraphElement
- func FileBlock(fileToken, viewType string) *lark.DocBlock
- func FileParagraphElement(fileToken, viewType string) *lark.DocParagraphElement
- func GalleryBlock(items ...*lark.DocImageItem) *lark.DocBlock
- func HorizontalLineBlock() *lark.DocBlock
- func ImageItem(fileToken string) *lark.DocImageItem
- func IndexDocLocation(index int64) *lark.UpdateDocLocation
- func JiraBlock(token, typ string) *lark.DocBlock
- func JiraParagraphElement(jiraToken, jiraType string) *lark.DocParagraphElement
- func Location(startIndex, endIndex int64) *lark.DocLocation
- func Paragraph(items ...*lark.DocParagraphElement) *lark.DocParagraph
- func ParagraphBlock(items ...*lark.DocParagraphElement) *lark.DocBlock
- func ParagraphStyle() *lark.DocParagraphStyle
- func PersonParagraphElement(openID string) *lark.DocParagraphElement
- func PollBlock(token string) *lark.DocBlock
- func RGBColor(r, g, b int, alpha float32) *lark.DocRGBColor
- func ReminderParagraphElement() *lark.DocParagraphElement
- func SheetBlock(sheetToken, sheetID string) *lark.DocBlock
- func StartOfZoneDocLocation() *lark.UpdateDocLocation
- func TableBlock(items ...*lark.DocTableRow) *lark.DocBlock
- func TableCell(body interface{}) *lark.DocTableCell
- func TableRow(items ...*lark.DocTableCell) *lark.DocTableRow
- func TextRunParagraphElement(txt string) *lark.DocParagraphElement
- func Title(txt string) *lark.DocParagraph
- func UpdateDocDeleteContentRangeRequest(location *lark.DocLocation) *lark.UpdateDocRequest
- func UpdateDocDeleteTableColumnsRequest(tableID string, columnStartIndex, columnEndIndex int64) *lark.UpdateDocRequest
- func UpdateDocDeleteTableRowRequest(tableID string, rowStartIndex, rowEndIndex int64) *lark.UpdateDocRequest
- func UpdateDocInsertBlocksRequest(body *lark.DocBody, location *lark.UpdateDocLocation) *lark.UpdateDocRequest
- func UpdateDocInsertParagraphElementsRequest(body *lark.DocParagraph, location *lark.UpdateDocLocation) *lark.UpdateDocRequest
- func UpdateDocInsertTableColumnRequest(tableID string, columnIndex int64) *lark.UpdateDocRequest
- func UpdateDocInsertTableRowRequest(tableID string, rowIndex int64) *lark.UpdateDocRequest
- func UpdateDocLocation(zoneID string, index int64, startOfZone, endOfZone bool) *lark.UpdateDocLocation
- func UpdateDocMergeTableCellsRequest(tableID string, ...) *lark.UpdateDocRequest
- func UpdateDocReplaceAllTextRequest(oldText, newText string) *lark.UpdateDocRequest
- func UpdateDocUnmergeTableCellsRequest(tableID string, mergedCellID string) *lark.UpdateDocRequest
- func UpdateDocUpdateTableColumnPropertiesRequest(tableID string, columnIndex, columnWidth int64) *lark.UpdateDocRequest
- func UpdateParagraphStyleRequest(location *lark.DocLocation, styles ...*UpdateParagraphStyle) *lark.UpdateDocRequest
- func UpdateTitle(value string) *lark.UpdateDocRequest
- type UpdateParagraphStyle
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DiagramBlock ¶
DiagramBlock 绘图或uml图
func DocsLinkParagraphElement ¶
func DocsLinkParagraphElement(val string) *lark.DocParagraphElement
DocsLinkParagraphElement 文档链接,可以根据链接自动识别为标题
func EmbeddedPageBlock ¶
EmbeddedPageBlock 内嵌网页,例如西瓜视频等
func EmptySheetBlock ¶
EmptySheetBlock 空的电子表格
func EmptyTableBlock ¶
EmptyTableBlock 格式化表格
func EndOfZoneDocLocation ¶
func EndOfZoneDocLocation() *lark.UpdateDocLocation
func EquationParagraphElement ¶
func EquationParagraphElement(equation string) *lark.DocParagraphElement
EquationParagraphElement LaTeX 公式
func FileParagraphElement ¶
func FileParagraphElement(fileToken, viewType string) *lark.DocParagraphElement
FileParagraphElement 文件的行内展示样式,会展示文件的名称
func IndexDocLocation ¶
func IndexDocLocation(index int64) *lark.UpdateDocLocation
func JiraParagraphElement ¶
func JiraParagraphElement(jiraToken, jiraType string) *lark.DocParagraphElement
JiraParagraphElement 行内的jira issue
func Paragraph ¶
func Paragraph(items ...*lark.DocParagraphElement) *lark.DocParagraph
func ParagraphBlock ¶
func ParagraphBlock(items ...*lark.DocParagraphElement) *lark.DocBlock
ParagraphBlock 文本段落
func ParagraphStyle ¶
func ParagraphStyle() *lark.DocParagraphStyle
func PersonParagraphElement ¶
func PersonParagraphElement(openID string) *lark.DocParagraphElement
PersonParagraphElement @用户
func ReminderParagraphElement ¶
func ReminderParagraphElement() *lark.DocParagraphElement
ReminderParagraphElement 任务列表截止时间,当且仅当这行是 checkBox 类型时才会生效
func StartOfZoneDocLocation ¶
func StartOfZoneDocLocation() *lark.UpdateDocLocation
func TableBlock ¶
func TableBlock(items ...*lark.DocTableRow) *lark.DocBlock
TableBlock 格式化表格 这个有问题,可以创建,但是无内容
func TableCell ¶
func TableCell(body interface{}) *lark.DocTableCell
func TableRow ¶
func TableRow(items ...*lark.DocTableCell) *lark.DocTableRow
func TextRunParagraphElement ¶
func TextRunParagraphElement(txt string) *lark.DocParagraphElement
TextRunParagraphElement 文本
func UpdateDocDeleteContentRangeRequest ¶
func UpdateDocDeleteContentRangeRequest(location *lark.DocLocation) *lark.UpdateDocRequest
UpdateDocDeleteContentRangeRequest 范围删除
func UpdateDocDeleteTableColumnsRequest ¶
func UpdateDocDeleteTableColumnsRequest(tableID string, columnStartIndex, columnEndIndex int64) *lark.UpdateDocRequest
UpdateDocDeleteTableColumnsRequest ... 删除范围 [ColumnStartIndex,ColumnEndIndex)
func UpdateDocDeleteTableRowRequest ¶
func UpdateDocDeleteTableRowRequest(tableID string, rowStartIndex, rowEndIndex int64) *lark.UpdateDocRequest
UpdateDocDeleteTableRowRequest ... 删除范围 [RowStartIndex,RowEndIndex)
func UpdateDocInsertBlocksRequest ¶
func UpdateDocInsertBlocksRequest(body *lark.DocBody, location *lark.UpdateDocLocation) *lark.UpdateDocRequest
UpdateDocInsertBlocksRequest 插入 blocks
func UpdateDocInsertParagraphElementsRequest ¶
func UpdateDocInsertParagraphElementsRequest(body *lark.DocParagraph, location *lark.UpdateDocLocation) *lark.UpdateDocRequest
UpdateDocInsertParagraphElementsRequest ...
func UpdateDocInsertTableColumnRequest ¶
func UpdateDocInsertTableColumnRequest(tableID string, columnIndex int64) *lark.UpdateDocRequest
UpdateDocInsertTableColumnRequest ...
func UpdateDocInsertTableRowRequest ¶
func UpdateDocInsertTableRowRequest(tableID string, rowIndex int64) *lark.UpdateDocRequest
UpdateDocInsertTableRowRequest ...
func UpdateDocLocation ¶
func UpdateDocLocation(zoneID string, index int64, startOfZone, endOfZone bool) *lark.UpdateDocLocation
UpdateDocLocation ...
func UpdateDocMergeTableCellsRequest ¶
func UpdateDocMergeTableCellsRequest(tableID string, rowStartIndex, rowEndIndex, columnStartIndex, columnEndIndex int64) *lark.UpdateDocRequest
UpdateDocMergeTableCellsRequest ...
func UpdateDocReplaceAllTextRequest ¶
func UpdateDocReplaceAllTextRequest(oldText, newText string) *lark.UpdateDocRequest
UpdateDocReplaceAllTextRequest ...
func UpdateDocUnmergeTableCellsRequest ¶
func UpdateDocUnmergeTableCellsRequest(tableID string, mergedCellID string) *lark.UpdateDocRequest
UpdateDocUnmergeTableCellsRequest ...
func UpdateDocUpdateTableColumnPropertiesRequest ¶
func UpdateDocUpdateTableColumnPropertiesRequest(tableID string, columnIndex, columnWidth int64) *lark.UpdateDocRequest
UpdateDocUpdateTableColumnPropertiesRequest ...
func UpdateParagraphStyleRequest ¶
func UpdateParagraphStyleRequest(location *lark.DocLocation, styles ...*UpdateParagraphStyle) *lark.UpdateDocRequest
UpdateParagraphStyleRequest ...
Types ¶
type UpdateParagraphStyle ¶
type UpdateParagraphStyle struct {
lark.DocParagraphStyle
// contains filtered or unexported fields
}
func SetParagraphStyleAlign ¶
func SetParagraphStyleAlign(val string) *UpdateParagraphStyle
func SetParagraphStyleHeadingLevel ¶
func SetParagraphStyleHeadingLevel(val int64) *UpdateParagraphStyle
func SetParagraphStyleList ¶
func SetParagraphStyleList(val *lark.DocStyleList) *UpdateParagraphStyle
func SetParagraphStyleQuote ¶
func SetParagraphStyleQuote(val bool) *UpdateParagraphStyle
Source Files
¶
- block_bitable.go
- block_callout.go
- block_chat_group.go
- block_code.go
- block_diagram.go
- block_docs_app.go
- block_embedded_page.go
- block_file.go
- block_gallery.go
- block_horizontal_line.go
- block_jira.go
- block_paragraph.go
- block_poll.go
- block_sheet.go
- block_table.go
- body.go
- image_item.go
- paragraph.go
- paragraph_element_docs_link.go
- paragraph_element_equation.go
- paragraph_element_file.go
- paragraph_element_jira.go
- paragraph_element_person.go
- paragraph_element_reminder.go
- paragraph_element_text_run.go
- paragraph_style.go
- rgb_color.go
- table_cell.go
- table_row.go
- title.go
- update_delete_range.go
- update_delete_table_column.go
- update_delete_table_row.go
- update_insert_block.go
- update_insert_paragraph_element.go
- update_insert_table_column.go
- update_insert_table_row.go
- update_location.go
- update_merge_table_cell.go
- update_paragraph_style.go
- update_range.go
- update_replace_text.go
- update_title.go
- update_unmerge_table_cell.go
- update_update_table_column_property.go